@@ -67,8 +67,7 @@ precision.data.frame <- function(data,
     estimate = !!enquo(estimate),
     estimator = estimator,
     na_rm = na_rm,
-    event_level = event_level,
-    ... = ...
+    event_level = event_level
   )
 }
 
@@ -121,8 +120,7 @@ precision_vec <- function(truth,
     estimate = estimate,
     na_rm = na_rm,
     estimator = estimator,
-    cls = "factor",
-    ...
+    cls = "factor"
   )
 }
 
