@@ -67,8 +67,7 @@ rsq.data.frame <- function(data, truth, estimate, na_rm = TRUE, ...) {
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
-    na_rm = na_rm,
-    ... = ...
+    na_rm = na_rm
   )
 
 }
@@ -87,8 +86,7 @@ rsq_vec <- function(truth, estimate, na_rm = TRUE, ...) {
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
-    cls = "numeric",
-    ...
+    cls = "numeric"
   )
 
 }
