@@ -157,8 +157,7 @@ gain_curve_vec <- function(truth,
     estimate = estimate,
     na_rm = na_rm,
     estimator = estimator,
-    cls = c("factor", "numeric"),
-    ...
+    cls = c("factor", "numeric")
   )
 }
 
@@ -313,16 +312,6 @@ autoplot.gain_df <- function(object, ...) {
 
   chart <- chart %+%
 
-    # gain curve
-    ggplot2::geom_line(
-      mapping = ggplot2::aes(
-        x = !!.percent_tested,
-        y = !!.percent_found,
-        !!! interact_expr
-      ),
-      data = object
-    ) %+%
-
     # boundary poly
     ggplot2::geom_polygon(
       mapping = ggplot2::aes(
@@ -335,6 +324,16 @@ autoplot.gain_df <- function(object, ...) {
       alpha = 0.4
     ) %+%
 
+    # gain curve
+    ggplot2::geom_line(
+      mapping = ggplot2::aes(
+        x = !!.percent_tested,
+        y = !!.percent_found,
+        !!! interact_expr
+      ),
+      data = object
+    ) %+%
+
     ggplot2::labs(
       x = "% Tested",
       y = "% Found"
