@@ -105,7 +105,6 @@ roc_auc.data.frame <- function(data,
     estimator = estimator,
     na_rm = na_rm,
     event_level = event_level,
-    ... = ...,
     metric_fn_options = list(options = options)
   )
 }
@@ -133,8 +132,7 @@ roc_auc_vec <- function(truth,
     estimate = estimate,
     estimator = estimator,
     na_rm = na_rm,
-    cls = c("factor", "numeric"),
-    ...
+    cls = c("factor", "numeric")
   )
 }
 
