@@ -2,13 +2,11 @@ context("Balanced Accuracy")
 
 # ------------------------------------------------------------------------------
 
-lst <- data_altman()
-pathology <- lst$pathology
-path_tbl <- lst$path_tbl
-
-pred_ch <- quote(scan)
-
 test_that('Two class', {
+  lst <- data_altman()
+  pathology <- lst$pathology
+  path_tbl <- lst$path_tbl
+
   expect_equal(
     bal_accuracy(pathology, truth = "pathology", estimate = "scan")[[".estimate"]],
     ( sens(path_tbl)[[".estimate"]] + spec(path_tbl)[[".estimate"]] )/2
@@ -23,12 +21,22 @@ test_that('Two class', {
   )
 })
 
+test_that("`event_level = 'second'` should be identical to 'first'", {
+  lst <- data_altman()
+  pathology <- lst$pathology
+  path_tbl <- lst$path_tbl
+
+  expect_identical(
+    bal_accuracy_vec(pathology$pathology, pathology$scan, event_level = "first"),
+    bal_accuracy_vec(pathology$pathology, pathology$scan, event_level = "second")
+  )
+})
+
 # ------------------------------------------------------------------------------
 
-multi_ex <- data_three_by_three()
-micro <- data_three_by_three_micro()
-
 test_that('Three class', {
+  multi_ex <- data_three_by_three()
+  micro <- data_three_by_three_micro()
 
   expect_equal(
     bal_accuracy(multi_ex, estimator = "macro")[[".estimate"]],
