@@ -2,13 +2,11 @@ context("Specificity")
 
 # ------------------------------------------------------------------------------
 
-lst <- data_altman()
-pathology <- lst$pathology
-path_tbl <- lst$path_tbl
-
-pred_ch <- quote(scan)
-
 test_that('Two class', {
+  lst <- data_altman()
+  pathology <- lst$pathology
+  path_tbl <- lst$path_tbl
+
   expect_equal(
     spec(pathology, truth = "pathology", estimate = "scan")[[".estimate"]],
     54/86
@@ -27,12 +25,26 @@ test_that('Two class', {
   )
 })
 
+test_that("`event_level = 'second'` works", {
+  lst <- data_altman()
+  df <- lst$pathology
+
+  df_rev <- df
+  df_rev$pathology <- relevel(df_rev$pathology, "norm")
+  df_rev$scan <- relevel(df_rev$scan, "norm")
+
+  expect_equal(
+    spec_vec(df$pathology, df$scan),
+    spec_vec(df_rev$pathology, df_rev$scan, event_level = "second")
+  )
+})
+
 # ------------------------------------------------------------------------------
 
-multi_ex <- data_three_by_three()
-micro <- data_three_by_three_micro()
-
 test_that('Three class', {
+  multi_ex <- data_three_by_three()
+  micro <- data_three_by_three_micro()
+
   expect_equal(
     spec(multi_ex, estimator = "macro")[[".estimate"]],
     macro_metric(spec_binary)
