@@ -12,7 +12,8 @@ test_that("AUNP is equivalent to macro_weighted estimator", {
 test_that("AUNP errors on binary case", {
   expect_error(
     roc_aunp(two_class_example, truth, Class1),
-    "The number of levels in"
+    "The number of levels in",
+    class = "dplyr_error"
   )
 })
 
